@@ -11,11 +11,7 @@ from mypy.nodes import (
     Var,
 )
 
-from refurb.checks.common import (
-    check_for_loop_like,
-    is_name_unused_in_contexts,
-    is_placeholder,
-)
+from refurb.checks.common import check_for_loop_like, is_name_unused_in_contexts, stringify
 from refurb.error import Error
 
 
@@ -70,22 +66,28 @@ def check_enumerate_call(
             TupleExpr(items=[NameExpr() as index, NameExpr() as value]),
             CallExpr(
                 callee=NameExpr(fullname="builtins.enumerate"),
-                args=[NameExpr(node=Var(type=ty))],
+                args=[NameExpr(node=Var(type=ty)) as enumerate_arg],
             ),
         ) if is_sequence_type(str(ty)):
-            check_unused_index_or_value(index, value, contexts, errors)
+            check_unused_index_or_value(index, value, contexts, errors, enumerate_arg)
 
 
 def check_unused_index_or_value(
-    index: NameExpr, value: NameExpr, contexts: list[Node], errors: list[Error]
+    index: NameExpr,
+    value: NameExpr,
+    contexts: list[Node],
+    errors: list[Error],
+    enumerate_arg: NameExpr,
 ) -> None:
-    if is_placeholder(index) or is_name_unused_in_contexts(index, contexts):
-        errors.append(ErrorInfo.from_node(index, "Index is unused, use `for x in y` instead"))
+    if is_name_unused_in_contexts(index, contexts):
+        msg = f"Index is unused, use `for {stringify(value)} in {stringify(enumerate_arg)}` instead"  # noqa: E501
 
-    if is_placeholder(value) or is_name_unused_in_contexts(value, contexts):
-        errors.append(
-            ErrorInfo.from_node(value, "Value is unused, use `for x in range(len(y))` instead")
-        )
+        errors.append(ErrorInfo.from_node(index, msg))
+
+    if is_name_unused_in_contexts(value, contexts):
+        msg = f"Value is unused, use `for {stringify(index)} in range(len({stringify(enumerate_arg)}))` instead"  # noqa: E501
+
+        errors.append(ErrorInfo.from_node(value, msg))
 
 
 # TODO: allow for any type that supports the Sequence protocol
