@@ -2,6 +2,7 @@ import os
 import sys
 from collections import defaultdict
 from contextlib import suppress
+from operator import itemgetter
 from pathlib import Path
 from subprocess import PIPE, run
 
@@ -97,11 +98,7 @@ NODES: dict[str, type] = {x.__name__: x for x in METHOD_NODE_MAPPINGS.values()}
 
 
 def node_type_prompt() -> list[str]:
-    return sorted(
-        fzf(
-            list(NODES.keys()), args=["--prompt", "type> ", "--multi"]
-        ).splitlines()
-    )
+    return sorted(fzf(list(NODES.keys()), args=["--prompt", "type> ", "--multi"]).splitlines())
 
 
 def filename_prompt() -> Path:
@@ -120,9 +117,7 @@ def filename_prompt() -> Path:
 
 
 def prefix_prompt() -> str:
-    return fzf(
-        [""], args=["--prompt", "prefix> ", "--print-query", "--query", "FURB"]
-    )
+    return fzf([""], args=["--prompt", "prefix> ", "--print-query", "--query", "FURB"])
 
 
 def build_imports(names: list[str]) -> str:
@@ -133,7 +128,7 @@ def build_imports(names: list[str]) -> str:
 
     return "\n".join(
         f"from {module} import {', '.join(names)}"
-        for module, names in sorted(modules.items(), key=lambda x: x[0])
+        for module, names in sorted(modules.items(), key=itemgetter(0))
     )
 
 
